=== modified file 'NEWS'
--- NEWS	2007-07-16 23:50:03 +0000
+++ NEWS	2007-07-19 14:11:55 +0000
@@ -1,3 +1,13 @@
+0.19.0	UNRELEASED
+
+ FEATURES
+
+  * Show tags in bzr viz. (Jelmer)
+
+ UI
+  
+  * Improve Preferences dialog layout. (Jelmer)
+
 0.18.0  2007-07-17
 
  FEATURES

=== modified file '__init__.py'
--- __init__.py	2007-07-16 23:50:03 +0000
+++ __init__.py	2007-07-17 02:55:14 +0000
@@ -33,7 +33,7 @@
 
 import bzrlib
 
-__version__ = '0.18.0'
+__version__ = '0.19.0'
 version_info = tuple(int(n) for n in __version__.split('.'))
 
 

=== modified file 'commit.py'
--- commit.py	2007-07-19 12:57:26 +0000
+++ commit.py	2007-07-19 13:16:31 +0000
@@ -155,11 +155,11 @@
                         proxy_obj, 'org.freedesktop.NetworkManager')
                 try:
                     # 3 is the enum value for STATE_CONNECTED
-                    self._check_local.set_active(dbus_iface.state() != 3) # FIXME: We need better way of finding if net is available, as above fails for me running KDE (MateuszKorniak).  
-                                                                          # <dbus_bindings.DBusException instance at 0xb66e38cc> : The name org.freedesktop.NetworkManager was not provided by any .service files
-                except Exception,e:
-                    self._check_local.set_active(False) # Assuming commits non local seems sane to me  (MateuszKorniak).
-                    print "ERROR: dbus_iface.state() failed with: %r : %s" % (e,e)
+                    self._check_local.set_active(dbus_iface.state() != 3)
+                except dbus.DBusException, e:
+                    # Silently drop errors. While DBus may be 
+                    # available, NetworkManager doesn't necessarily have to be
+                    mutter("unable to get networkmanager state: %r" % e)
                 
         # Create the file list
         self._create_file_view()

=== modified file 'diff.py'
--- diff.py	2007-07-16 10:27:35 +0000
+++ diff.py	2007-07-19 12:37:23 +0000
@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: UTF-8 -*-
 """Difference window.
 

=== modified file 'logview.py'
--- logview.py	2007-05-19 09:58:19 +0000
+++ logview.py	2007-07-19 14:20:52 +0000
@@ -30,7 +30,7 @@
     start.
     """
 
-    def __init__(self, revision=None, scroll=True):
+    def __init__(self, revision=None, scroll=True, tags=None):
         super(LogView, self).__init__()
         if scroll:
             self.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
@@ -43,7 +43,7 @@
         self._clicked_callback = None
 
         if revision is not None:
-            self.set_revision(revision)
+            self.set_revision(revision, tags=tags)
 
     def set_show_callback(self, callback):
         self._show_callback = callback
@@ -51,7 +51,7 @@
     def set_go_callback(self, callback):
         self._go_callback = callback
 
-    def set_revision(self, revision):
+    def set_revision(self, revision, tags=None):
         self._revision = revision
         self.revision_id.set_text(revision.revision_id)
         if revision.committer is not None:
@@ -68,6 +68,7 @@
             self.branchnick_label.set_text("")
 
         self._add_parents(revision.parent_ids)
+        self._add_tags(tags)
 
     def _show_clicked_cb(self, widget, revid, parentid):
         """Callback for when the show button for a parent is clicked."""
@@ -77,6 +78,26 @@
         """Callback for when the go button for a parent is clicked."""
         self._go_callback(revid)
 
+    def _add_tags(self, tags):
+        if tags == []:
+            self.tags_list.hide()
+            self.tags_label.hide()
+            return
+
+        for widget in self.tags_widgets:
+            self.tags_list.remove(widget)
+
+        self.tags_widgets = []
+
+        for tag in tags:
+            widget = gtk.Label(tag)
+            widget.set_selectable(True)
+            self.tags_widgets.append(widget)
+            self.tags_list.add(widget)
+        self.tags_list.show_all()
+        self.tags_label.show_all()
+        
+
     def _add_parents(self, parent_ids):
         for widget in self.parents_widgets:
             self.parents_table.remove(widget)
@@ -127,7 +148,7 @@
         vbox.show()
 
     def _create_headers(self):
-        self.table = gtk.Table(rows=4, columns=2)
+        self.table = gtk.Table(rows=5, columns=2)
         self.table.set_row_spacings(6)
         self.table.set_col_spacings(6)
         self.table.show()
@@ -196,6 +217,22 @@
         align.show()
         self.timestamp.show()
 
+        align = gtk.Alignment(1.0, 0.5)
+        self.tags_label = gtk.Label()
+        self.tags_label.set_markup("<b>Tags:</b>")
+        align.add(self.tags_label)
+        align.show()
+        self.table.attach(align, 0, 1, 4, 5, gtk.FILL, gtk.FILL)
+        self.tags_label.show()
+
+        align = gtk.Alignment(0.0, 0.5)
+        self.tags_list = gtk.VBox()
+        align.add(self.tags_list)
+        self.table.attach(align, 1, 2, 4, 5, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        align.show()
+        self.tags_list.show()
+        self.tags_widgets = []
+
         return self.table
 
     def _create_parents_table(self):

=== modified file 'preferences.py'
--- preferences.py	2007-07-13 21:59:53 +0000
+++ preferences.py	2007-07-19 13:09:18 +0000
@@ -26,6 +26,11 @@
 
 class PreferencesWindow(gtk.Dialog):
     """Displays global preferences windows."""
+    # Note that we don't allow configuration of aliases or 
+    # default log formats. This is because doing so wouldn't make 
+    # a lot of sense to pure GUI users. Users that need these settings 
+    # will already be familiar with the configuration file.
+
     def __init__(self, config=None):
         """ Initialize the Status window. """
         super(PreferencesWindow, self).__init__(flags=gtk.DIALOG_MODAL)
@@ -46,11 +51,9 @@
         align.add(label)
         table.attach(align, 0, 1, 0, 1, gtk.FILL, gtk.FILL)
 
-        align = gtk.Alignment(0.0, 0.5)
         self.username = gtk.Entry()
-        align.add(self.username)
         self.username.set_text(self.config.username())
-        table.attach(align, 1, 2, 0, 1, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        table.attach(self.username, 1, 2, 0, 1, gtk.EXPAND | gtk.FILL, gtk.FILL)
 
         align = gtk.Alignment(1.0, 0.5)
         label = gtk.Label()
@@ -58,11 +61,9 @@
         align.add(label)
         table.attach(align, 0, 1, 1, 2, gtk.FILL, gtk.FILL)
 
-        align = gtk.Alignment(0.0, 0.5)
         self.email = gtk.Entry()
         self.email.set_text(self.config.gpg_signing_command())
-        align.add(self.email)
-        table.attach(align, 1, 2, 1, 2, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        table.attach(self.email, 1, 2, 1, 2, gtk.EXPAND | gtk.FILL, gtk.FILL)
 
         align = gtk.Alignment(1.0, 0.5)
         label = gtk.Label()
@@ -70,7 +71,6 @@
         align.add(label)
         table.attach(align, 0, 1, 2, 3, gtk.FILL, gtk.FILL)
 
-        align = gtk.Alignment(0.0, 0.5)
         sigvals = gtk.VBox()
         self.check_sigs_if_possible = gtk.RadioButton(None, 
                                                       "_Check if possible")
@@ -82,8 +82,7 @@
                                                 "Check _never")
         sigvals.pack_start(self.check_sigs_never)
         # FIXME: Set default
-        align.add(sigvals)
-        table.attach(align, 1, 2, 2, 3, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        table.attach(sigvals, 1, 2, 2, 3, gtk.EXPAND | gtk.FILL, gtk.FILL)
 
         align = gtk.Alignment(1.0, 0.5)
         label = gtk.Label()
@@ -91,7 +90,6 @@
         align.add(label)
         table.attach(align, 0, 1, 3, 4, gtk.FILL, gtk.FILL)
 
-        align = gtk.Alignment(0.0, 0.5)
         create_sigs = gtk.VBox()
         self.create_sigs_when_required = gtk.RadioButton(None, 
                                                          "Sign When _Required")
@@ -103,26 +101,23 @@
             self.create_sigs_when_required, "Sign _Never")
         create_sigs.pack_start(self.create_sigs_never)
         # FIXME: Set default
-        align.add(create_sigs)
-        table.attach(align, 1, 2, 3, 4, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        table.attach(create_sigs, 1, 2, 3, 4, gtk.EXPAND | gtk.FILL, gtk.FILL)
 
         return table
 
     def _create_pluginpage(self):
-        vbox = gtk.VBox(False, 2)
-        vbox.set_border_width(6)
-
+        paned = gtk.VPaned()
         scrolledwindow = gtk.ScrolledWindow()
         scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         model = gtk.ListStore(str, str)
         treeview = gtk.TreeView()
         scrolledwindow.add(treeview)
+        paned.pack1(scrolledwindow, resize=True, shrink=False)
 
         table = gtk.Table(columns=2)
         table.set_row_spacings(6)
         table.set_col_spacings(6)
 
-
         def row_selected(tv, path, tvc):
             p = bzrlib.plugin.all_plugins()[model[path][0]]
             from inspect import getdoc
@@ -195,11 +190,13 @@
         for name in plugin_names:
             model.append([name, getattr(plugins[name], '__file__', None)])
                  
-        vbox.pack_start(scrolledwindow, expand=True, fill=True)
-
-        vbox.pack_start(table)
-
-        return vbox
+        scrolledwindow = gtk.ScrolledWindow()
+        scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        scrolledwindow.add_with_viewport(table)
+        paned.pack2(scrolledwindow, resize=False, shrink=True)
+        paned.show()
+
+        return paned
 
     def _create(self):
         self.set_default_size(600, 600)

=== modified file 'setup.py'
--- setup.py	2007-07-15 15:15:59 +0000
+++ setup.py	2007-07-17 02:55:14 +0000
@@ -63,7 +63,7 @@
 
 setup(
     name = "bzr-gtk",
-    version = "0.18.0",
+    version = "0.19.0",
     maintainer = "Jelmer Vernooij",
     maintainer_email = "jelmer@samba.org",
     description = "GTK+ Frontends for various Bazaar commands",

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2007-07-15 16:39:21 +0000
+++ viz/branchwin.py	2007-07-19 14:11:55 +0000
@@ -204,7 +204,12 @@
 
         self.back_button.set_sensitive(len(self.parent_ids[revision]) > 0)
         self.fwd_button.set_sensitive(len(self.children[revision]) > 0)
-        self.logview.set_revision(revision)
+        tags = []
+        if self.branch.supports_tags():
+            tagdict = self.branch.tags.get_reverse_tag_dict()
+            if tagdict.has_key(revision.revision_id):
+                tags = tagdict[revision.revision_id]
+        self.logview.set_revision(revision, tags)
 
     def _back_clicked_cb(self, *args):
         """Callback for when the back button is clicked."""

